<?php
/**
 * Keeway functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Keeway
 */

if ( ! function_exists( 'keeway_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function keeway_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Keeway, use a find and replace
		 * to change 'keeway' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'keeway', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		add_theme_support( 'post-formats', array(
			'audio',
			'video',
		) );	
		
		
		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'keeway_image_1200_1200', 1200,1200, true );
		add_image_size( 'keeway_image_481_768', 481,768, true );
		add_image_size( 'keeway_image_300_300', 300,300, true );
		add_image_size( 'keeway_image_850_530', 850,530, true );
		add_image_size( 'keeway_image_840_430', 840,430, true );
		add_image_size( 'keeway_image_120_100', 120,100, true );
		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'keeway' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );
		
		/*
		 * Set woocommerce support  
		 * 
		 */
		add_theme_support( 'woocommerce' );		

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'keeway_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 100,
			'width'       => 80,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}

endif;
add_action( 'after_setup_theme', 'keeway_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function keeway_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'keeway_content_width', 640 );
}
add_action( 'after_setup_theme', 'keeway_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function keeway_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'keeway' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'keeway' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Sidebar', 'keeway' ),
		'id'            => 'sidebar-2',
		'description'   => esc_html__( 'Add widgets here.', 'keeway' ),
		'before_widget' => '<div class="col-xl-3 col-lg-3 col-md-6 col-sm-6 col-12"><div class="footer_single_sidebar">',
		'after_widget'  => '</div></div>',
		'before_title'  => '<h3  class="wg_title">',
		'after_title'   => '</h3>',
	) );	
}
add_action( 'widgets_init', 'keeway_widgets_init' );


/**
 * Enqueue scripts and styles.
 */
function keeway_scripts() {
	
	// Load CSS Files
	wp_enqueue_style('google-font' , '//fonts.googleapis.com/css2?family=Quicksand:wght@400;500;700;800&display=swap');		
	wp_enqueue_style('bootstrap' , get_template_directory_uri(). '/assets/bootstrap/css/bootstrap.min.css');	
	wp_enqueue_style('all' , get_template_directory_uri(). '/assets/fontawesome/css/all.css');	
	wp_enqueue_style('fontawesome' , get_template_directory_uri(). '/assets/fontawesome/css/fontawesome.css');
	wp_enqueue_style('font-awesome-brands' , get_template_directory_uri(). '/assets/fontawesome/css/brands.css');	
	wp_enqueue_style('font-awesome-solid' , get_template_directory_uri(). '/assets/fontawesome/css/solid.css');	
	wp_enqueue_style('themify-icons' , get_template_directory_uri(). '/assets/fonts/themify-icons.css');	
	wp_enqueue_style('owl-carousel' , get_template_directory_uri(). '/assets/owlcarousel/css/owl.carousel.css');	
	wp_enqueue_style('owl-theme' , get_template_directory_uri(). '/assets/owlcarousel/css/owl.theme.default.css');	
	wp_enqueue_style('venobox' , get_template_directory_uri(). '/assets/css/venobox.css');
	wp_enqueue_style('YouTubePopUp' , get_template_directory_uri(). '/assets/css/YouTubePopUp.css');
	wp_enqueue_style('animate' , get_template_directory_uri(). '/assets/css/animate.css');		
	wp_enqueue_style('meanmenu' , get_template_directory_uri(). '/assets/css/slicknav.css');	
	wp_enqueue_style('keeway-main-style' , get_template_directory_uri(). '/assets/css/style.css');	
	wp_enqueue_style('responsive' , get_template_directory_uri(). '/assets/css/responsive.css');	

	wp_enqueue_style( 'keeway-style', get_stylesheet_uri() );

	// Load JS Files
	wp_enqueue_script( 'html5shiv', get_template_directory_uri() . '/js/html5shiv.min.js', array(), '3.7.2' );	
	wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9' ); 	
	wp_enqueue_script( 'respond', get_template_directory_uri() . '/js/respond.min.js', array(), '1.4.2' );
	wp_script_add_data( 'respond', 'conditional', 'lt IE 9' ); 	
	
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/bootstrap/js/bootstrap.min.js', array('jquery'), '685972', true );
	wp_enqueue_script( 'jquery-inview', get_template_directory_uri() . '/assets/js/jquery.inview.min.js', array('jquery'), '685972', true );
	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/assets/owlcarousel/js/owl.carousel.min.js', array('jquery'), '685972', true );wp_enqueue_script( 'jquery.mixitup', get_template_directory_uri() . '/assets/js/jquery.mixitup.js', array('jquery'), '685972', true );
	wp_enqueue_script( 'scrolltopcontrol', get_template_directory_uri() . '/assets/js/scrolltopcontrol.js', array('jquery'), '685971', true );
	wp_enqueue_script( 'venobox-min', get_template_directory_uri() . '/assets/js/venobox.min.js', array('jquery'), '685972', true );	
	wp_enqueue_script( 'YouTubePopUp', get_template_directory_uri() . '/assets/js/YouTubePopUp.jquery.js', array('jquery'), '685972', true );	
	wp_enqueue_script( 'jquery-appear', get_template_directory_uri() . '/assets/js/jquery.appear.js', array('jquery'), '685972', true );
	wp_enqueue_script( 'jquery-meanmenu', get_template_directory_uri() . '/assets/js/jquery.slicknav.js', array('jquery'), '685972', true );
	wp_enqueue_script( 'wow', get_template_directory_uri() . '/assets/js/wow.js', array('jquery'), '685972', true );
	wp_enqueue_script( 'keeway-scripts', get_template_directory_uri() . '/assets/js/scripts.js', array('jquery'), '685971', true );
	
	
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'keeway_scripts' );


function keeway_main_menu() {
		wp_nav_menu( array(
		'theme_location'    => 'menu-1',
		'depth'             => 5,
		'container'         => false,
		'menu_class'        => '',
		'fallback_cb'       => 'keeway_navwalker::fallback',
		
		)
	); 	
}

function keeway_mobile_menu() {
		wp_nav_menu( array(
		'theme_location'    => 'menu-1',
		'depth'             => 5,
		'container'         => false,
		'menu_class'        => ' ',
		'fallback_cb'       => 'keeway_navwalker::fallback',
		
		)
	); 	
}


// modify search widget
function keeway_my_search_form( $form ) {
	$form = '
		
			
			<form role="search" method="get" id="searchform" class="searchform" action="' . esc_url(home_url( '/' )) . '" >
				<div class="input-group">
					<input type="text" value="' . esc_attr(get_search_query()) . '" name="s" id="s" class="form-control search_field" placeholder="' . esc_attr__('Enter Keyword ...' , 'keeway') .'">
					<span class="input-group-btn">
						<button class="btn btn-default search_btn" type="submit"><i class="fa fa-search"></i></button>
					</span>
				</div>
			</form>
			
		
        ';
	return $form;
}
add_filter( 'get_search_form', 'keeway_my_search_form' );

// comment list modify

function keeway_comments($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>

<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
	<div class="single_comment">
		<div class="media">
			<div class="comment_avatar">
				<?php echo get_avatar( $comment, 70 ); ?>
			</div>

			<div class="media-body text-left comment_single">
				
				<h5 class="media-heading"><?php comment_author_link() ?></h5> 
				
				<div class="com_time"><?php echo esc_html(get_comment_date('F j, Y')); ?> <?php echo esc_html(get_comment_date('g:i')); ?></div> 
				
				<?php if ($comment->comment_approved == '0') : ?>
				<p><em><?php esc_html_e('Your comment is awaiting moderation.','keeway'); ?></em></p>
				<?php endif; ?>
				 <?php comment_text(); ?>	
				<div class="creply_link"> <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?></div>				 
			</div>
		</div>
	</div>				
</li>


<?php } 

// comment box title change
add_filter( 'comment_form_defaults', 'keeway_remove_comment_form_allowed_tags' );
function keeway_remove_comment_form_allowed_tags( $defaults ) {

	$defaults['comment_notes_after'] = '';
	$defaults['comment_notes_before'] = '';
	return $defaults;

}

function keeway_comment_reform ($arg) {

$arg['title_reply'] = esc_html__('Write your comment Here','keeway');
$arg['comment_field'] = '<div class="row"><div class="form-group col-md-12"><textarea id="comment" class="comment_field form-control" name="comment" cols="77" rows="3" placeholder="'. esc_attr__("Write your Comment", "keeway").'" aria-required="true"></textarea></div></div>';


return $arg;

}
add_filter('comment_form_defaults','keeway_comment_reform');

// comment form modify

function keeway_modify_comment_form_fields($fields){
	$commenter = wp_get_current_commenter();
	$req	   = get_option( 'require_name_email' );

	$fields['author'] = '<div class="row"><div class="form-group col-md-4"><input type="text" name="author" id="author" value="'. esc_attr( $commenter['comment_author'] ) .'" placeholder="'. esc_attr__("Your Name *", "keeway").'" size="22" tabindex="1"'. ( $req ? 'aria-required="true"' : '' ).' class="input-name form-control" /></div>';

	$fields['email'] = '<div class="form-group col-md-4"><input type="text" name="email" id="email" value="'. esc_attr( $commenter['comment_author_email'] ) .'" placeholder="'.esc_attr__("Your Email *", "keeway").'" size="22" tabindex="2"'. ( $req ? 'aria-required="true"' : '' ).' class="input-email form-control"  /></div>';
	
	$fields['url'] = '<div class="form-group col-md-4"><input type="text" name="url" id="url" value="'. esc_attr( $commenter['comment_author_url'] ) .'" placeholder="'. esc_attr__("Website", "keeway").'" size="22" tabindex="2"'. ( $req ? 'aria-required="false"' : '' ).' class="input-url form-control"  /></div></div>';

	return $fields;
}
add_filter('comment_form_default_fields','keeway_modify_comment_form_fields');

function keeway_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;
	return $fields;
}
add_filter( 'comment_form_fields', 'keeway_move_comment_field_to_bottom' );
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}




/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/keeway-functions.php';
require get_template_directory() . '/inc/navwalker.php';
require get_template_directory() . '/inc/class-tgm-plugin-activation.php';
require get_template_directory() . '/inc/required-plugin.php';
require get_template_directory() . '/inc/demo_install.php';

if ( ! function_exists( 'keeway_readmore_content' ) ) :
/**
 * Prints readmore content
 */
function keeway_readmore_content($word) {
	echo wp_trim_words( get_the_content(), $word, '' );
}
endif;


function keeway_excerpt_length( $length ) {
    return 33;
}
add_filter( 'excerpt_length', 'keeway_excerpt_length', 999 );

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581327904&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        