<?php

// File Security Check
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class KeewayBlogWidget extends \Elementor\Widget_Base{
	
	public function get_name() {
		
		return 'keeway-blog';
	}
	public function get_icon() {
		
		return 'eicon-shortcode';
	}
	public function get_title() {
		return esc_html__('Blog' , 'keeway');
	}
	
	public function get_categories() {
		return ['keeway-category'];
	}
	
	protected function register_controls() {

		$this->start_controls_section(
		'keeway_blog',
			[
				'label' => esc_html__( 'Blog', 'keeway' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_control(
			'sec_title',
			[
				'label' => esc_html__( 'Title', 'keeway' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA ,
				'default' => 'Latest <span>blog</span>',
			]
		);	
		
		$this->add_control(
			'number_of_post',
			[
				'label' => esc_html__( 'Number of Post', 'keeway' ),
				'type' => \Elementor\Controls_Manager::TEXT ,
				'default' => '3',
			]
		);	

		
		$this->add_control(
			'read_more_btn_text',
			[
				'label' => esc_html__( 'Button Text', 'keeway' ),
				'type' => \Elementor\Controls_Manager::TEXT ,
				'default' => 'Learn More',
			]
		);	
		
		$this->end_controls_section();

	}
	
	protected function render(){	
	
	$sec_title = $this->get_settings_for_display( 'sec_title' );
	$number_of_post = $this->get_settings_for_display( 'number_of_post' );
	$read_more_btn_text = $this->get_settings_for_display( 'read_more_btn_text' );

	?>
		
		<!-- START HOME BLOG -->
		<section id="blog" class="home_blog section-padding">
			<div class="container">
				<div class="section-title text-center wow zoomIn">
					<h2><?php echo keeway_wp_kses($sec_title);?></h2>
					<div class="sec_icon"><span></span><span></span><span></span></div>
				</div>					
				<div class="blog_wrap grid-blog">
					<div class="row">
					<?php
					// WP_Query arguments
					$args = array(
						'post_type'              => array( 'post' ),
						'posts_per_page'         => $number_of_post,
					);

					// The Query
					$keeway_post_query = new WP_Query( $args );

					// The Loop
					if ( $keeway_post_query->have_posts() ) {
						while ( $keeway_post_query->have_posts() ) {
							$keeway_post_query->the_post();
							$keeway_btn_text = get_post_meta(get_the_ID(),'_keeway_btn_text', true);
							
							?>
							
							<div class="col-xl-4 col-lg-4 col-md-6 col-sm-6 col-12 wow fadeIn">
								<div class="home_single_blog">
									<?php the_post_thumbnail('keeway_image_850_530', array('class' => 'img-responsive blog-photo', ));?>
									<div class="home_blog_text">									
										 <h4><a href="<?php the_permalink();?>"><?php the_title();?></a></h4>										
										 <p><?php keeway_readmore_content(15);?></p>
										<a class="blog_btn" href="<?php the_permalink();?>"><?php echo esc_html($read_more_btn_text);?></a>
									</div>
								</div><!--- END SINGLE BLOG POST -->
							</div><!--- END COL -->
					
							
					<?php	}
					} else {
						// no posts found
					}

					// Restore original Post Data
					wp_reset_postdata();
			?>		
					</div><!--- END ROW -->	
				</div>
			</div><!--- END CONTAINER -->
		</section>
		<!-- END HOME BLOG -->

<?php

	}

}
