<?php

// File Security Check
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class KeewayPricingWidget extends \Elementor\Widget_Base{
	
	public function get_name() {
		
		return 'keeway-pricing';
	}
	public function get_icon() {
		
		return 'eicon-shortcode';
	}
	public function get_title() {
		return esc_html__('Pricing' , 'keeway');
	}
	
	public function get_categories() {
		return ['keeway-category'];
	}
	
	protected function register_controls() {

		$this->start_controls_section(
		'keeway_pricing',
			[
				'label' => esc_html__( 'Pricing', 'keeway' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
	
		$this->add_control(
			'sec_title',
			[
				'label' => esc_html__( 'Title', 'keeway' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA ,
				'default' => 'Pricing <span>Table</span>',
			]
		);	
		
		$this->add_control(
			'number_of_post',
			[
				'label' => esc_html__( 'Number of Post', 'keeway' ),
				'type' => \Elementor\Controls_Manager::TEXT ,
				'default' => '3',
			]
		);	
			
			
		$this->end_controls_section();

	}
	
	protected function render(){		
	
		$sec_title = $this->get_settings_for_display( 'sec_title' );
		$number_of_post = $this->get_settings_for_display( 'number_of_post' );
		
		?>
		
		<!-- START PRICING -->
		<section id="pricing" class="pricing_table">
			<div class="container text-center">
				<div class="section-title wow zoomIn">
					<h2><?php echo keeway_wp_kses($sec_title);?></h2>
					<div class="sec_icon"><span></span><span></span><span></span></div>
				</div>
					
				<div class="row">
					<?php

					// WP_Query arguments
					$args = array(
					'post_type'              => array( 'pricing' ),
					'posts_per_page'         => $number_of_post,
					);

					// The Query
					$keeway_pricing_query = new WP_Query( $args );

					// The Loop
					if ( $keeway_pricing_query->have_posts() ) {
					while ( $keeway_pricing_query->have_posts() ) {
					$keeway_pricing_query->the_post();
					$keeway_pricing_period = get_post_meta(get_the_ID(),'_keeway_pricing_period', true);
					$keeway_pricing_amount = get_post_meta(get_the_ID(),'_keeway_pricing_amount', true);
					$keeway_pricing_group_field_opt = get_post_meta(get_the_ID(),'_keeway_pricing_group_field_opt', true);
					$keeway_pricing_btn_text = get_post_meta(get_the_ID(),'_keeway_pricing_btn_text', true);
					$keeway_pricing_btn_link = get_post_meta(get_the_ID(),'_keeway_pricing_btn_link', true);
					?>

					<div class="col-xl-4 col-lg-4 col-md-6 col-sm-6 col-12 text-center wow fadeInUp">
						<div class="pricing-table feature">
							<h3><?php the_title();?></h3>
							<div class="price">
								<span><?php echo esc_html($keeway_pricing_amount);?></span>
								<?php echo esc_html($keeway_pricing_period);?>
							</div>
							<ul class="pricing-list">
								<?php
								foreach ( (array) $keeway_pricing_group_field_opt as $key => $pricing_entry ) {

									$feature = $icon = '';

									if ( isset( $pricing_entry['_keeway_pricing_icon'] ) )
										$icon = $pricing_entry['_keeway_pricing_icon'];	

									if ( isset( $pricing_entry['_keeway_single_feature'] ) )
										$feature = $pricing_entry['_keeway_single_feature'];	

									?>
									
										<li><i class="<?php echo esc_attr($icon);?>"></i> <?php echo esc_html($feature);?></li>
								
								<?php } ?>	

							</ul>
							
							<div class="pricing-btn">
								<a href="<?php echo esc_html($keeway_pricing_btn_link);?>" class="btn-light-bg"><?php echo esc_html($keeway_pricing_btn_text);?></a>
							</div>
						</div><!-- END PRICING TABLE -->
					</div><!-- END COL -->

					<?php	}
					} else {
						// no posts found
					}

					// Restore original Post Data
					wp_reset_postdata(); ?>

				</div><!--END  ROW  -->
			</div><!-- END CONTAINER  -->
		</section>
		<!-- END PRICING -->

<?php

	}

}
